@@ -21,14 +21,18 @@ class Parse:
         spans = html.xpath("//nav[@class='panel video-panel-info']/div/span")
         if strongs:
             info = {"id": "", "date": "", "runtime": "", "director": [], "studio": [], "tag": [], "genres": [],
-                    "actors": [],"rating":"","link":"","smallimage":"","bigimage":""}
+                    "actors": [],"rating":"","link":"","smallimage":"","bigimage":"","title":""}
+            info["title"] = html.xpath("//h2[@class='title is-4']/strong")[0].text
             bigimage = html.xpath("//div[@class='column column-video-cover']/a/@href")
             info['bigimage'] = str(bigimage[0])
             for strong, span in zip(strongs, spans):
                 title = strong.text
                 content = span
                 if "番號" in title:
-                    info['id'] = content.text
+                    info['id'] =''.join(content.itertext())
+                    if info["id"]:
+                        info["title"]=info["title"].replace(info["id"],"")
+                        if info["title"] and info["title"].startswith(" "):info["title"]=info["title"][1:]
                 elif "日期" in title:
                     info['date'] = content.text
                 elif "時長" in title:
@@ -130,7 +134,7 @@ class Parse:
             return str.join(';',result)
 
     def format(self,info,previewimages,magnets):
-        detailinfo= {"id": "", "date": "", "runtime": 0, "javdblink":"","director": "", "directorlink": "", "studio": "", "studiolink": "",
+        detailinfo= {"id": "", "date": "", "runtime": 0, "javdblink":"","title":"","director": "", "directorlink": "", "studio": "", "studiolink": "",
                      "tag": "", "taglink": "","genres": "","genreslink": "","actors": "","actorslink": "","rating":0.00,"ratingnum":0,
                      "smallimage":"","bigimage":"","previewimages":"","magnets":""}
 
@@ -138,6 +142,7 @@ class Parse:
         detailinfo['date'] = info['date']
         if info['runtime']: detailinfo['runtime'] = int(info['runtime'])
         detailinfo['javdblink'] = info['link']
+        detailinfo['title'] = info['title'].replace("'","").replace("\n","").replace("\t","").replace("\r","").replace(u"\xa0","")
         detailinfo['director'] = self.getinfofromdict(info['director'],'name').replace("'","")
         detailinfo['directorlink'] = self.getinfofromdict(info['director'],'link')
         detailinfo['studio'] = self.getinfofromdict(info['studio'], 'name').replace("'","")
@@ -196,6 +201,7 @@ class Javdb_Sqlite:
                date           CHAR(10),
                runtime        INTEGER DEFAULT 0,
                javdblink      CHAR(10),
+               title          TEXT,
                director       TEXT,
                directorlink   TEXT,
                studio         TEXT,
@@ -226,9 +232,9 @@ class Javdb_Sqlite:
         if not os.path.exists(self.savepath):self.createdb()
         conn = sqlite3.connect(self.savepath)
         cursor = conn.cursor()
-        sqltext = f"INSERT INTO movie (id,date,runtime,javdblink,director,directorlink,studio,studiolink,tag,taglink,genres,genreslink,actors,actorslink,rating,ratingnum,smallimage,bigimage,previewimages,magnets) " \
-                  f"VALUES ('{detailinfo['id']}', '{detailinfo['date']}', {detailinfo['runtime']}, '{detailinfo['javdblink']}','{detailinfo['director']}','{detailinfo['directorlink']}','{detailinfo['studio']}','{detailinfo['studiolink']}','{detailinfo['tag']}','{detailinfo['taglink']}','{detailinfo['genres']}','{detailinfo['genreslink']}','{detailinfo['actors']}','{detailinfo['actorslink']}',{detailinfo['rating']}, {detailinfo['ratingnum']},'{detailinfo['smallimage']}','{detailinfo['bigimage']}','{detailinfo['previewimages']}','{detailinfo['magnets']}') " \
-                  f"ON CONFLICT(id) DO UPDATE SET date = '{detailinfo['date']}',runtime={detailinfo['runtime']},javdblink='{detailinfo['javdblink']}',director='{detailinfo['director']}',directorlink='{detailinfo['directorlink']}',studio='{detailinfo['studio']}',studiolink='{detailinfo['studiolink']}',tag='{detailinfo['tag']}',taglink='{detailinfo['taglink']}',genres='{detailinfo['genres']}',genreslink='{detailinfo['genreslink']}',actors='{detailinfo['actors']}',actorslink='{detailinfo['actorslink']}',rating={detailinfo['rating']},ratingnum={detailinfo['ratingnum']},smallimage='{detailinfo['smallimage']}',bigimage='{detailinfo['bigimage']}',previewimages='{detailinfo['previewimages']}',magnets='{detailinfo['magnets']}';"
+        sqltext = f"INSERT INTO detail (id,date,runtime,javdblink,title,director,directorlink,studio,studiolink,tag,taglink,genres,genreslink,actors,actorslink,rating,ratingnum,smallimage,bigimage,previewimages,magnets) " \
+                  f"VALUES ('{detailinfo['id']}', '{detailinfo['date']}', {detailinfo['runtime']}, '{detailinfo['javdblink']}', '{detailinfo['title']}','{detailinfo['director']}','{detailinfo['directorlink']}','{detailinfo['studio']}','{detailinfo['studiolink']}','{detailinfo['tag']}','{detailinfo['taglink']}','{detailinfo['genres']}','{detailinfo['genreslink']}','{detailinfo['actors']}','{detailinfo['actorslink']}',{detailinfo['rating']}, {detailinfo['ratingnum']},'{detailinfo['smallimage']}','{detailinfo['bigimage']}','{detailinfo['previewimages']}','{detailinfo['magnets']}') " \
+                  f"ON CONFLICT(id) DO UPDATE SET date = '{detailinfo['date']}',runtime={detailinfo['runtime']},javdblink='{detailinfo['javdblink']}',title='{detailinfo['title']}',director='{detailinfo['director']}',directorlink='{detailinfo['directorlink']}',studio='{detailinfo['studio']}',studiolink='{detailinfo['studiolink']}',tag='{detailinfo['tag']}',taglink='{detailinfo['taglink']}',genres='{detailinfo['genres']}',genreslink='{detailinfo['genreslink']}',actors='{detailinfo['actors']}',actorslink='{detailinfo['actorslink']}',rating={detailinfo['rating']},ratingnum={detailinfo['ratingnum']},smallimage='{detailinfo['smallimage']}',bigimage='{detailinfo['bigimage']}',previewimages='{detailinfo['previewimages']}',magnets='{detailinfo['magnets']}';"
         cursor.execute(sqltext)
         conn.commit()
         conn.close()
